package com.yidian.shenghuoquan.border.ui

import android.content.Intent
import androidx.activity.viewModels
import com.yidian.bcommon.constant.IntentConstants
import com.yidian.bcommon.constant.XEventConfig
import com.yidian.bcommon.constant.XRouterPathConstants
import com.yidian.bcommon.mvvm.BaseMvvmActivity
import com.yidian.shenghuoquan.border.R
import com.yidian.shenghuoquan.border.adapter.OrderConfirmCommodityListAdapter
import com.yidian.shenghuoquan.border.databinding.BorderActivityConfirmOrderBinding
import com.yidian.shenghuoquan.border.dto.PickupPoint
import com.yidian.shenghuoquan.border.dto.Shipping
import com.yidian.xarc.xevent.XBaseEvent
import com.yidian.xarc.xevent.XEventManager
import com.yidian.xpage.XPageManager
import org.greenrobot.eventbus.Subscribe
import org.greenrobot.eventbus.ThreadMode
import timber.log.Timber

/**
 * 确认订单
 */
class ConfirmOrderActivity : BaseMvvmActivity<BorderActivityConfirmOrderBinding, ConfirmOrderViewModel>() {

  private var marketingId: String? = null// 活动id

  private val adapter by lazy { OrderConfirmCommodityListAdapter() }

  override val layoutId: Int = R.layout.border_activity_confirm_order

  override val vm: ConfirmOrderViewModel by viewModels()

  override fun initView() {
    XEventManager.register(this)
    subscribeUiEvent()
    initList()
    getIntentData(intent)
  }

  private fun initList() {
    binding.rvGoodsList.adapter = adapter
  }

  private fun getIntentData(intent: Intent?) {
    val paramsMap = intent?.getSerializableExtra(XRouterPathConstants.ParamsKey)
    if (paramsMap != null) {
      paramsMap as HashMap<String, String?>
      marketingId = paramsMap["marketing_id"]
      vm.requestConfirmOrderInfo(paramsMap)
    }
  }

  private fun subscribeUiEvent() {
    vm.goodsSuccessEvent.observe(this, {
      adapter.setList(it)
    })
    vm.chooseCouponEvent.observe(this) {
      // 将最新的优惠券列表传递过去
      val hashMap = HashMap<String, Any?>()
      hashMap[IntentConstants.KEY_EXTRA_COUPON_LIST] = it
      XPageManager.push(XRouterPathConstants.CHOOSE_VOUCHER_ACTIVITY, hashMap)
    }
    vm.choosePointEvent.observe(this) {
      // 将选择的自提点id传递过去
      marketingId?.let { id ->
        val hashMap = HashMap<String, Any?>()
        hashMap[IntentConstants.KEY_EXTRA_PICKUP_POINT_ID] = it
        hashMap[IntentConstants.KEY_EXTRA_MARKETING_ID] = id
        Timber.e("活动id: $id")
        XPageManager.push(XRouterPathConstants.PICKUP_POINT_ACTIVITY, hashMap)
      }

    }

  }

  override fun onDestroy() {
    super.onDestroy()
    XEventManager.unRegister(this)
  }

  @Subscribe(sticky = false, threadMode = ThreadMode.MAIN)
  fun onEvent(event: XBaseEvent?) {
    when (event?.name) {
      XEventConfig.CONFIRM_ORDER_CHOOSE_POINT_SUCCESS -> {
        // 选择自提点成功
        val point = event.body as PickupPoint
        vm.choosePickUpPointSuccess(point)
      }
      XEventConfig.CONFIRM_ORDER_CHOOSE_COUPON_SUCCESS -> {
        // 选择优惠券成功
        val selectedCouponIndex = event.body as Int
        vm.chooseVoucherSuccess(selectedCouponIndex)
      }
    }
  }

}
