package com.yidian.shenghuoquan.border.ui

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import com.yidian.bcommon.mvvm.BaseViewModel
import com.yidian.bcommon.utils.ToastUtils
import com.yidian.shenghuoquan.border.dto.CouponDto
import com.yidian.shenghuoquan.border.dto.GoodsDto
import com.yidian.shenghuoquan.border.dto.PickupPoint
import com.yidian.shenghuoquan.border.dto.Shipping
import com.yidian.shenghuoquan.border.http.OrderRemoteDataSource


class ConfirmOrderViewModel : BaseViewModel() {

  private var originalAmount: Double = 0.00// 原价总和
  var couponAmount: Double = 0.00// 优惠券金额

  var selectedPickUpPoint = MutableLiveData<Shipping?>()// 自提点
  var receivingName = MutableLiveData<String>()// 收货人姓名
  var receivingPhone = MutableLiveData<String>()//收货人电话
  var selectedCoupon = MutableLiveData<CouponDto?>()// 选中的优惠券
  var couponsAvailableList = MutableLiveData<List<CouponDto>?>()// 可用优惠券列表
  var totalAmount = MutableLiveData(0.00)// 合计金额 = 原价 - 优惠
  var remark = MutableLiveData<String>()

  /**
   * 商品列表成功 Event
   */
  private val _goodsSuccessEvent = MutableLiveData<List<GoodsDto>?>()
  val goodsSuccessEvent: LiveData<List<GoodsDto>?> = _goodsSuccessEvent

  /**
   * 选择自提点 Event
   */
  private val _choosePointEvent = MutableLiveData<Long?>()
  val choosePointEvent: LiveData<Long?> = _choosePointEvent

  /**
   * 选择优惠券 Event
   */
  private val _chooseCouponEvent = MutableLiveData<List<CouponDto>?>()
  val chooseCouponEvent: LiveData<List<CouponDto>?> = _chooseCouponEvent

  /**
   * 请求订单信息
   */
  fun requestConfirmOrderInfo(paramsMap: HashMap<String, String?>) {
    OrderRemoteDataSource.requestOrderConfirm(paramsMap) {
      if (it == null) {
        return@requestOrderConfirm
      }
      selectedPickUpPoint.value = it.shipping
      receivingName.value = it.shipping?.receiverName ?: ""
      receivingPhone.value = it.shipping?.receiverMobile ?: ""
      _goodsSuccessEvent.value = it.goodsList
      calculateOriginalAmount(it.goodsList)
      couponsAvailableList.value = it.couponList
    }
  }

  /**
   * 计算商品原价 = 数量 * 单价
   */
  private fun calculateOriginalAmount(goodsDto: List<GoodsDto>?) {
    if (goodsDto.isNullOrEmpty()) {
      return
    }
    goodsDto.forEach {
      originalAmount = originalAmount.plus(it.price * it.goodsNum)
    }
    // 计算出合计
    calculateTotalAmount()
  }

  /**
   * 计算商品合计 = 原价 - 优惠
   */
  private fun calculateTotalAmount() {
    totalAmount.value = originalAmount - couponAmount
  }

  /**
   * 选择自提点，如果有上次选中的带过去自提点id
   */
  fun choosePickUpPoint() {
    // 带过去当前选中自提点id
    _choosePointEvent.value = selectedPickUpPoint.value?.takePlaceId
  }

  fun choosePickUpPointSuccess(point: PickupPoint) {
    selectedPickUpPoint.value = Shipping(
      takePlaceId = point.takePlaceId,
      takePlaceName = point.takePlaceName,
      contactName = point.contactName,
      phone = point.phone,
      address = point.address
    )
  }

  /**
   * 选择代金券, 如果有上次选中的带过去最新的列表
   */
  fun chooseVoucher() {
    _chooseCouponEvent.value = couponsAvailableList.value
  }

  fun chooseVoucherSuccess(selectedIndex: Int) {
    // 获取选中的优惠券
    val coupon = couponsAvailableList.value?.get(selectedIndex)
    //将该优惠券更新为选中状态
    coupon?.selected = true
    selectedCoupon.value = coupon
    couponAmount = coupon?.amount?.toDouble() ?: 0.00
    // 重新计算相关金额
    calculateTotalAmount()
  }

  /**
   * 创建订单
   */
  fun createOrder() {
    val paramsMap = HashMap<String, String?>()
    paramsMap["business_from"] = "2"
    paramsMap["user_id"] = "510235230818"
    // todo 添加其他参数

    OrderRemoteDataSource.requestCreateOrder(paramsMap) {
      ToastUtils.showShort("创建订单成功${it?.orderId}")
    }
  }

  /**
   * 立即支付
   */
  fun payNow() {

  }

}
